summaryrefslogtreecommitdiffstats
path: root/libtdepim/qutf7codec.cpp
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:23:13 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-21 14:23:13 -0600
commitba2a3ce341c0c71bbbcf350fcbcd60c552220b31 (patch)
tree08ba9504290f461f1244dded6b37fc4db00847ab /libtdepim/qutf7codec.cpp
parentd5b298be14c173d62e8fbc6a3803ba8f657f3dcb (diff)
downloadtdepim-ba2a3ce341c0c71bbbcf350fcbcd60c552220b31.tar.gz
tdepim-ba2a3ce341c0c71bbbcf350fcbcd60c552220b31.zip
Rename obsolete tq methods to standard names
Diffstat (limited to 'libtdepim/qutf7codec.cpp')
-rw-r--r--libtdepim/qutf7codec.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/libtdepim/qutf7codec.cpp b/libtdepim/qutf7codec.cpp
index b0076172..d390e649 100644
--- a/libtdepim/qutf7codec.cpp
+++ b/libtdepim/qutf7codec.cpp
@@ -137,10 +137,10 @@ int TQUtf7Codec::heuristicContentMatch(const char* chars, int len) const
}
class TQUtf7Decoder : public TQTextDecoder {
// the storage for our tqunicode char until it's finished
ushort uc;
// the state of the base64 decoding
// can be 0 (just finished three tqunicode chars)
// 1 (have the upper 6 bits of uc already)
// 2 (have the upper 12 bits of uc already)
// 3 (have the upper 2 bits of uc already)
@@ -148,7 +148,7 @@ class TQUtf7Decoder : public TQTextDecoder {
// 7 (have the upper 10 bits of uc already)
// => n (have the upper (n * 6) % 16 bits of uc already)
// "stepNo" cycles through all it's values every three
- // tqunicode chars.
+ // unicode chars.
char stepNo;
// remembers if we are in shifted-sequence mode
bool shifted;
@@ -462,7 +462,7 @@ public:
#endif
// source and destination cursor
- const TQChar * s = uc.tqunicode();
+ const TQChar * s = uc.unicode();
TQCString::Iterator t = result.data();
if ( uc.isNull() ) {
@@ -473,7 +473,7 @@ public:
// normal operation:
for (int i = 0 ; i < len_in_out ;
i++/*, checkOutBuf(result,maxreslen,t,i,len_in_out,5)*/ ) {
- ushort ch = s[i].tqunicode();
+ ushort ch = s[i].unicode();
//
// first, we check whether we might get around encoding:
@@ -137,10 +137,10 @@ int TQUtf7Codec::heuristicContentMatch(const char* chars, int len) const
}
class TQUtf7Decoder : public TQTextDecoder {
- // the storage for our tqunicode char until it's finished
+ // the storage for our unicode char until it's finished
ushort uc;
// the state of the base64 decoding
@@ -137,10 +137,10 @@ int TQUtf7Codec::heuristicContentMatch(const char* chars, int len) const
ushort uc;
// the state of the base64 decoding
- // can be 0 (just finished three tqunicode chars)
+ // can be 0 (just finished three unicode chars)
// 1 (have the upper 6 bits of uc already)
// 2 (have the upper 12 bits of uc already)